package com.ruoyi.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.SysHelp;

/**
 * helpMapper接口
 * 
 * @author ruoyi
 * @date 2023-06-09
 */
public interface SysHelpMapper  extends BaseMapper<SysHelp>
{
    /**
     * 查询help
     * 
     * @param id help主键
     * @return help
     */
    public SysHelp selectSysHelpById(Long id);

    /**
     * 查询help列表
     * 
     * @param sysHelp help
     * @return help集合
     */
    public List<SysHelp> selectSysHelpList(SysHelp sysHelp);

    /**
     * 新增help
     * 
     * @param sysHelp help
     * @return 结果
     */
    public int insertSysHelp(SysHelp sysHelp);

    /**
     * 修改help
     * 
     * @param sysHelp help
     * @return 结果
     */
    public int updateSysHelp(SysHelp sysHelp);

    /**
     * 删除help
     * 
     * @param id help主键
     * @return 结果
     */
    public int deleteSysHelpById(Long id);

    /**
     * 批量删除help
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysHelpByIds(Long[] ids);
}
